==> zio-aws-lightsail_2.12-5.17.206.1-sources.jar: zio/aws/lightsail/model/InputOrigin.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.ResourceName
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class InputOrigin(
    name: Optional[ResourceName] = Optional.Absent,
    regionName: Optional[zio.aws.lightsail.model.RegionName] = Optional.Absent,
    protocolPolicy: Optional[zio.aws.lightsail.model.OriginProtocolPolicyEnum] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.InputOrigin = {
    import InputOrigin.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.InputOrigin
      .builder()
      .optionallyWith(
        name.map(value => ResourceName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(regionName.map(value => value.unwrap))(_.regionName)
      .optionallyWith(protocolPolicy.map(value => value.unwrap))(
        _.protocolPolicy
      )
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.InputOrigin.ReadOnly =
    zio.aws.lightsail.model.InputOrigin.wrap(buildAwsValue())
}
object InputOrigin {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.InputOrigin
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.InputOrigin =
      zio.aws.lightsail.model.InputOrigin(
        name.map(value => value),
        regionName.map(value => value),
        protocolPolicy.map(value => value)
      )
    def name: Optional[ResourceName]
    def regionName: Optional[zio.aws.lightsail.model.RegionName]
    def protocolPolicy
        : Optional[zio.aws.lightsail.model.OriginProtocolPolicyEnum]
    def getName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("name", name)
    def getRegionName: ZIO[Any, AwsError, zio.aws.lightsail.model.RegionName] =
      AwsError.unwrapOptionField("regionName", regionName)
    def getProtocolPolicy
        : ZIO[Any, AwsError, zio.aws.lightsail.model.OriginProtocolPolicyEnum] =
      AwsError.unwrapOptionField("protocolPolicy", protocolPolicy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.InputOrigin
  ) extends zio.aws.lightsail.model.InputOrigin.ReadOnly {
    override val name: Optional[ResourceName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.lightsail.model.primitives.ResourceName(value))
    override val regionName: Optional[zio.aws.lightsail.model.RegionName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.regionName())
        .map(value => zio.aws.lightsail.model.RegionName.wrap(value))
    override val protocolPolicy
        : Optional[zio.aws.lightsail.model.OriginProtocolPolicyEnum] =
      zio.aws.core.internal
        .optionalFromNullable(impl.protocolPolicy())
        .map(value =>
          zio.aws.lightsail.model.OriginProtocolPolicyEnum.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.InputOrigin
  ): zio.aws.lightsail.model.InputOrigin.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lightsail_2.12-7.28.29.1-sources.jar: zio/aws/lightsail/model/InputOrigin.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.{Integer, ResourceName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class InputOrigin(
    name: Optional[ResourceName] = Optional.Absent,
    regionName: Optional[zio.aws.lightsail.model.RegionName] = Optional.Absent,
    protocolPolicy: Optional[zio.aws.lightsail.model.OriginProtocolPolicyEnum] =
      Optional.Absent,
    responseTimeout: Optional[Integer] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.InputOrigin = {
    import InputOrigin.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.InputOrigin
      .builder()
      .optionallyWith(
        name.map(value => ResourceName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(regionName.map(value => value.unwrap))(_.regionName)
      .optionallyWith(protocolPolicy.map(value => value.unwrap))(
        _.protocolPolicy
      )
      .optionallyWith(responseTimeout.map(value => value: java.lang.Integer))(
        _.responseTimeout
      )
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.InputOrigin.ReadOnly =
    zio.aws.lightsail.model.InputOrigin.wrap(buildAwsValue())
}
object InputOrigin {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.InputOrigin
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.InputOrigin =
      zio.aws.lightsail.model.InputOrigin(
        name.map(value => value),
        regionName.map(value => value),
        protocolPolicy.map(value => value),
        responseTimeout.map(value => value)
      )
    def name: Optional[ResourceName]
    def regionName: Optional[zio.aws.lightsail.model.RegionName]
    def protocolPolicy
        : Optional[zio.aws.lightsail.model.OriginProtocolPolicyEnum]
    def responseTimeout: Optional[Integer]
    def getName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("name", name)
    def getRegionName: ZIO[Any, AwsError, zio.aws.lightsail.model.RegionName] =
      AwsError.unwrapOptionField("regionName", regionName)
    def getProtocolPolicy
        : ZIO[Any, AwsError, zio.aws.lightsail.model.OriginProtocolPolicyEnum] =
      AwsError.unwrapOptionField("protocolPolicy", protocolPolicy)
    def getResponseTimeout: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("responseTimeout", responseTimeout)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.InputOrigin
  ) extends zio.aws.lightsail.model.InputOrigin.ReadOnly {
    override val name: Optional[ResourceName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.lightsail.model.primitives.ResourceName(value))
    override val regionName: Optional[zio.aws.lightsail.model.RegionName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.regionName())
        .map(value => zio.aws.lightsail.model.RegionName.wrap(value))
    override val protocolPolicy
        : Optional[zio.aws.lightsail.model.OriginProtocolPolicyEnum] =
      zio.aws.core.internal
        .optionalFromNullable(impl.protocolPolicy())
        .map(value =>
          zio.aws.lightsail.model.OriginProtocolPolicyEnum.wrap(value)
        )
    override val responseTimeout: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.responseTimeout())
      .map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.InputOrigin
  ): zio.aws.lightsail.model.InputOrigin.ReadOnly = new Wrapper(impl)
}
